@@ -33,7 +33,15 @@ G_BEGIN_DECLS
 
 #define GS_TYPE_APP (gs_app_get_type ())
 
-G_DECLARE_FINAL_TYPE (GsApp, gs_app, GS, APP, GObject)
+G_DECLARE_DERIVABLE_TYPE (GsApp, gs_app, GS, APP, GObject)
+
+struct _GsAppClass
+{
+	GObjectClass		 parent_class;
+	void			 (*to_string)	(GsApp		*app,
+						 GString	*str);
+	gpointer		 padding[30];
+};
 
 /**
  * GsAppKudo:
@@ -100,8 +108,13 @@ typedef enum {
 } GsAppQuality;
 
 GsApp		*gs_app_new			(const gchar	*id);
+G_DEPRECATED_FOR(gs_app_set_from_unique_id)
 GsApp		*gs_app_new_from_unique_id	(const gchar	*unique_id);
+void		 gs_app_set_from_unique_id	(GsApp		*app,
+						 const gchar	*unique_id);
 gchar		*gs_app_to_string		(GsApp		*app);
+void		 gs_app_to_string_append	(GsApp		*app,
+						 GString	*str);
 
 const gchar	*gs_app_get_id			(GsApp		*app);
 void		 gs_app_set_id			(GsApp		*app,
