@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2015-2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2015-2017 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -32,8 +32,23 @@ gs_appstream_create_app (GsPlugin *plugin, AsApp *item, GError **error)
 {
 	const gchar *unique_id = as_app_get_unique_id (item);
 	GsApp *app = gs_plugin_cache_lookup (plugin, unique_id);
+
+	/* if the app we found has the "match-any-prefix" quirk and our item does
+	 * not, then we create a new one because ours will be "complete", and
+	 * using the mentioned quirk will lead to a different behavior (e.g. it'll
+	 * be refined using refine_wildcard, it won't allow a management plugin to
+	 * be set, etc.)  */
+	if (app != NULL && gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX) &&
+	    !as_app_has_quirk (item, AS_APP_QUIRK_MATCH_ANY_PREFIX)) {
+		g_debug ("Looking for %s, got %s but has 'match-any-prefix' quirk "
+			 "so we create a new one instead.",
+			 unique_id, gs_app_get_unique_id (app));
+		g_clear_object (&app);
+	}
+
 	if (app == NULL) {
-		app = gs_app_new_from_unique_id (unique_id);
+		app = gs_plugin_app_new (plugin, NULL);
+		gs_app_set_from_unique_id (app, unique_id);
 		gs_app_set_metadata (app, "GnomeSoftware::Creator",
 				     gs_plugin_get_name (plugin));
 		if (!gs_appstream_refine_app (plugin, app, item, error)) {
@@ -303,53 +318,11 @@ gs_appstream_copy_metadata (GsApp *app, AsApp *item)
 	}
 }
 
-GsApp *
-gs_appstream_create_runtime (GsPlugin *plugin,
-			     GsApp *parent,
-			     const gchar *runtime)
-{
-	g_autofree gchar *source = NULL;
-	g_auto(GStrv) split = NULL;
-	g_autoptr(GsApp) app_cache = NULL;
-	g_autoptr(GsApp) app = NULL;
-
-	/* get the name/arch/branch */
-	split = g_strsplit (runtime, "/", -1);
-	if (g_strv_length (split) != 3)
-		return NULL;
-
-	/* create the complete GsApp from the single string */
-	app = gs_app_new (split[0]);
-	source = g_strdup_printf ("runtime/%s", runtime);
-	gs_app_add_source (app, source);
-	gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_FLATPAK);
-	gs_app_set_kind (app, AS_APP_KIND_RUNTIME);
-	gs_app_set_branch (app, split[2]);
-	gs_app_set_scope (app, gs_app_get_scope (parent));
-
-	/* search in the cache */
-	app_cache = gs_plugin_cache_lookup (plugin, gs_app_get_unique_id (app));
-	if (app_cache != NULL) {
-		/* since the cached runtime can have been created somewhere else
-		 * (we're using a global cache), we need to make sure that a
-		 * source is set */
-		if (gs_app_get_source_default (app_cache) == NULL)
-			gs_app_add_source (app_cache, source);
-		return g_steal_pointer (&app_cache);
-	}
-
-	/* save in the cache */
-	gs_plugin_cache_add (plugin, NULL, app);
-	return g_steal_pointer (&app);
-}
-
 static void
 gs_refine_item_management_plugin (GsPlugin *plugin, GsApp *app, AsApp *item)
 {
 	GPtrArray *bundles;
 	const gchar *management_plugin = NULL;
-	const gchar *runtime = NULL;
-	guint i;
 
 	/* allow override */
 	management_plugin = as_app_get_metadata_item (item, "GnomeSoftware::Plugin");
@@ -358,32 +331,9 @@ gs_refine_item_management_plugin (GsPlugin *plugin, GsApp *app, AsApp *item)
 
 	/* find the default bundle kind */
 	bundles = as_app_get_bundles (item);
-	for (i = 0; i < bundles->len; i++) {
+	for (guint i = 0; i < bundles->len; i++) {
 		AsBundle *bundle = g_ptr_array_index (bundles, i);
-		AsBundleKind kind = as_bundle_get_kind (bundle);
-
 		gs_app_add_source (app, as_bundle_get_id (bundle));
-
-		/* automatically add runtime */
-		if (kind == AS_BUNDLE_KIND_FLATPAK) {
-			runtime = as_bundle_get_runtime (bundle);
-			if (runtime != NULL) {
-				g_autoptr(GsApp) app2 = NULL;
-				app2 = gs_appstream_create_runtime (plugin, app, runtime);
-				if (app2 != NULL) {
-					if (app == app2) {
-						g_warning ("%s runtime cannot have runtime!",
-							   gs_app_get_unique_id (app));
-						break;
-					}
-					g_debug ("runtime for %s is %s",
-						 gs_app_get_unique_id (app),
-						 runtime);
-					gs_app_set_update_runtime (app, app2);
-				}
-			}
-			break;
-		}
 	}
 }
 
@@ -530,6 +480,15 @@ gs_appstream_origin_valid (const gchar *origin)
 	return TRUE;
 }
 
+static gboolean
+gs_appstream_is_valid_project_group (AsApp *item)
+{
+	const gchar *project_group = as_app_get_project_group (item);
+	if (project_group == NULL)
+		return FALSE;
+	return as_utils_is_environment_id (project_group);
+}
+
 gboolean
 gs_appstream_refine_app (GsPlugin *plugin,
 			 GsApp *app,
@@ -559,12 +518,6 @@ gs_appstream_refine_app (GsPlugin *plugin,
 		gs_app_set_kind (app, as_app_get_kind (item));
 	}
 
-	/* is installed already */
-	if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN &&
-	    as_app_get_state (item) == AS_APP_STATE_INSTALLED) {
-		gs_app_set_state (app, as_app_get_state (item));
-	}
-
 	/* is compatible */
 	req = as_app_get_require_by_value (item,
 					   AS_REQUIRE_KIND_ID,
@@ -584,6 +537,7 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	switch (gs_app_get_kind (app)) {
 	case AS_APP_KIND_ADDON:
 	case AS_APP_KIND_CODEC:
+	case AS_APP_KIND_DRIVER:
 	case AS_APP_KIND_FIRMWARE:
 	case AS_APP_KIND_FONT:
 	case AS_APP_KIND_GENERIC:
@@ -608,16 +562,11 @@ gs_appstream_refine_app (GsPlugin *plugin,
 
 	/* set source */
 	if (gs_app_get_metadata_item (app, "appstream::source-file") == NULL) {
-#if AS_CHECK_VERSION(0,6,9)
 		AsFormat *format = as_app_get_format_by_kind (item, AS_FORMAT_KIND_DESKTOP);
 		if (format != NULL) {
 			gs_app_set_metadata (app, "appstream::source-file",
 					     as_format_get_filename (format));
 		}
-#else
-		gs_app_set_metadata (app, "appstream::source-file",
-				     as_app_get_source_file (item));
-#endif
 	}
 
 	/* scope */
@@ -721,8 +670,8 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	}
 
 	/* set project group */
-	if (as_app_get_project_group (item) != NULL &&
-	    gs_app_get_project_group (app) == NULL)
+	if (gs_app_get_project_group (app) == NULL &&
+	    gs_appstream_is_valid_project_group (item))
 		gs_app_set_project_group (app, as_app_get_project_group (item));
 
 	/* set developer name */
@@ -1078,6 +1027,54 @@ gs_appstream_add_popular (GsPlugin *plugin,
 	return TRUE;
 }
 
+static gboolean
+_as_app_is_recent (AsApp *app, guint64 age)
+{
+	AsRelease *rel;
+	guint64 ts;
+	guint64 now;
+
+	rel = as_app_get_release_default (app);
+	if (rel == NULL)
+		return FALSE;
+	ts = as_release_get_timestamp (rel);
+	if (ts == 0)
+		return FALSE;
+	now = (guint64) g_get_real_time () / G_USEC_PER_SEC;
+	return (now - ts) < age;
+}
+
+gboolean
+gs_appstream_add_recent (GsPlugin *plugin,
+			 AsStore *store,
+			 GsAppList *list,
+			 guint64 age,
+			 GCancellable *cancellable,
+			 GError **error)
+{
+	GPtrArray *array;
+	g_autoptr(AsProfileTask) ptask = NULL;
+
+	/* find out how many packages are in each category */
+	ptask = as_profile_start_literal (gs_plugin_get_profile (plugin),
+					  "appstream::add-recent");
+	g_assert (ptask != NULL);
+	array = as_store_get_apps (store);
+	for (guint i = 0; i < array->len; i++) {
+		g_autoptr(GsApp) app = NULL;
+		AsApp *item = g_ptr_array_index (array, i);
+		if (as_app_get_id (item) == NULL)
+			continue;
+		if (!_as_app_is_recent (item, age))
+			continue;
+		app = gs_appstream_create_app (plugin, item, error);
+		if (app == NULL)
+			return FALSE;
+		gs_app_list_add (list, app);
+	}
+	return TRUE;
+}
+
 gboolean
 gs_appstream_add_featured (GsPlugin *plugin,
 			   AsStore *store,
@@ -1113,6 +1110,7 @@ void
 gs_appstream_add_extra_info (GsPlugin *plugin, AsApp *app)
 {
 	const gchar *tmp;
+	g_autoptr(AsIcon) icon = NULL;
 
 	/* add more search terms */
 	switch (as_app_get_kind (app)) {
@@ -1127,35 +1125,60 @@ gs_appstream_add_extra_info (GsPlugin *plugin, AsApp *app)
 		break;
 	}
 
-	/* fix up these */
-	if (as_app_get_kind (app) == AS_APP_KIND_LOCALIZATION &&
-	    g_str_has_prefix (as_app_get_id (app),
-			      "org.fedoraproject.LangPack-")) {
-		g_autoptr(AsIcon) icon = NULL;
-
-		/* add icon */
+	/* add the gnome-software-specific 'Addon' group and ensure they
+	 * all have an icon set */
+	switch (as_app_get_kind (app)) {
+	case AS_APP_KIND_FONT:
+		as_app_add_category (app, "Addon");
+		as_app_add_category (app, "Font");
+		break;
+	case AS_APP_KIND_SHELL_EXTENSION:
+		as_app_add_category (app, "Addon");
+		as_app_add_category (app, "ShellExtension");
 		icon = as_icon_new ();
 		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
-		as_icon_set_name (icon, "accessories-dictionary-symbolic");
+		as_icon_set_name (icon, "application-x-addon-symbolic");
 		as_app_add_icon (app, icon);
-
-		/* add categories */
-		as_app_add_category (app, "Addons");
-		as_app_add_category (app, "Localization");
-	}
-
-	/* fall back for drivers */
-	if (as_app_get_kind (app) == AS_APP_KIND_DRIVER) {
-		g_autoptr(AsIcon) icon = NULL;
+		break;
+	case AS_APP_KIND_DRIVER:
+		as_app_add_category (app, "Addon");
+		as_app_add_category (app, "Driver");
 		icon = as_icon_new ();
 		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
 		as_icon_set_name (icon, "application-x-firmware-symbolic");
 		as_app_add_icon (app, icon);
-	}
-
-	/* fix up drivers with our nonstandard groups */
-	if (as_app_get_kind (app) == AS_APP_KIND_DRIVER) {
-		as_app_add_category (app, "Addons");
-		as_app_add_category (app, "Drivers");
+		break;
+	case AS_APP_KIND_LOCALIZATION:
+		as_app_add_category (app, "Addon");
+		as_app_add_category (app, "Localization");
+		icon = as_icon_new ();
+		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
+		as_icon_set_name (icon, "accessories-dictionary-symbolic");
+		as_app_add_icon (app, icon);
+		break;
+	case AS_APP_KIND_CODEC:
+		as_app_add_category (app, "Addon");
+		as_app_add_category (app, "Codec");
+		icon = as_icon_new ();
+		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
+		as_icon_set_name (icon, "application-x-addon");
+		as_app_add_icon (app, icon);
+		break;
+	case AS_APP_KIND_INPUT_METHOD:
+		as_app_add_category (app, "Addon");
+		as_app_add_category (app, "InputSource");
+		icon = as_icon_new ();
+		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
+		as_icon_set_name (icon, "system-run-symbolic");
+		as_app_add_icon (app, icon);
+		break;
+	case AS_APP_KIND_FIRMWARE:
+		icon = as_icon_new ();
+		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
+		as_icon_set_name (icon, "system-run-symbolic");
+		as_app_add_icon (app, icon);
+		break;
+	default:
+		break;
 	}
 }
