@@ -80,7 +80,7 @@ gs_plugin_initialize (GsPlugin *plugin)
 	gs_plugin_set_app_gtype (plugin, GS_TYPE_FLATPAK_APP);
 
 	/* used for self tests */
-	priv->destdir_for_tests = g_getenv ("GS_SELF_TEST_FLATPACK_DATADIR");
+	priv->destdir_for_tests = g_getenv ("GS_SELF_TEST_FLATPAK_DATADIR");
 }
 
 static gboolean
